##SnakeScan##
import SnakeScan

and use module to scan port 

For full compatibility, I recommend using python 3.x.x

 --l  need internet connection
 --h help
 --a All search port
 --t All search port threading
 --d dos
 --s single port search
 --i information about host
 